# exhausterr: Exhautive Error Handling / Railway Programming in Python

A library implementing error as values in Python with exhaustiveness verifiability, type safety and pattern matching. Brings flavors of Zig and Rust error handling to Python towards higher reliability in critical Python programs.<br>
Integrate errors as part of you control flow and leverage the full potential of type checkers to assert code behavior. This utility should help you applying the base principles of railway programming while squeezing their full potential out of type checkers.

# Installation
Requires Python>=3.11. Based on hatchling as the build backend.

```console
pip install exhausterr
```

Or if using hatch frontend:
```
hatch shell
```